@@ -6,9 +6,7 @@ use smoltcp::{
     time::{Duration, Instant},
 };
 use std::{future::Future, sync::Arc};
-use tokio::sync::Notify;
-use tokio::time::sleep;
-use tokio::{pin, select};
+use tokio::{pin, select, sync::Notify, time::sleep};
 
 pub struct Reactor {
     socket_alloctor: Arc<SocketAlloctor>,
@@ -19,6 +17,7 @@ async fn run<S: device::Interface + 'static>(
     mut interf: EthernetInterface<'static, FutureDevice<S>>,
     sockets: Arc<SocketAlloctor>,
     notify: Arc<Notify>,
+    stopper: Arc<Notify>,
 ) {
     let default_timeout = Duration::from_secs(60);
     let timer = sleep(default_timeout.into());
@@ -42,6 +41,7 @@ async fn run<S: device::Interface + 'static>(
                 _ = &mut timer => {},
                 _ = device.wait() => {}
                 _ = notify.notified() => {}
+                _ = stopper.notified() => break,
             };
         }
 
@@ -62,10 +62,11 @@ impl Reactor {
     pub fn new<S: device::Interface + 'static>(
         interf: EthernetInterface<'static, FutureDevice<S>>,
         buffer_size: BufferSize,
+        stopper: Arc<Notify>,
     ) -> (Self, impl Future<Output = ()> + Send) {
         let socket_alloctor = Arc::new(SocketAlloctor::new(buffer_size));
         let notify = Arc::new(Notify::new());
-        let fut = run(interf, socket_alloctor.clone(), notify.clone());
+        let fut = run(interf, socket_alloctor.clone(), notify.clone(), stopper);
 
         (
             Reactor {
